# CONLL-2003 synthetic data set for SLING parser

This folder contains the [CoNLL-2003](https://www.clips.uantwerpen.be/conll2003/ner/)
corpora annotated with SLING frame annotations. The annotations have been
produced using a SLING parser trained on OntoNotes. That means that the
annotations are synthetic and should only be used for toy experiments. 
However, this allows you to try out the parser trainer for SLING.

First download and unpack the files into the SLING directory:

```
curl -o /tmp/conll-2003-sempar.tar.gz http://www.jbox.dk/sling/conll-2003-sempar.tar.gz
tar -xvf /tmp/conll-2003-sempar.tar.gz
```

This will put the following files into `local/conll2003`:

| File                        | Description                                   |
|-----------------------------|-----------------------------------------------|
| eng.train                   | Original CoNLL 2003 training corpus           |
| eng.testa                   | Original CoNLL 2003 development corpus        |
| eng.testb                   | Original CoNLL 2003 test corpus               |
| eng.train.zip               | CoNLL 2003 training corpus in SLING format    |
| eng.testa.zip               | CoNLL 2003 development corpus in SLING format |
| eng.testb.zip               | CoNLL 2003 test corpus in SLING format        |
| commons                     | SLING commons store for training parser       |
| BUILD                       | BUILD file for building tools                 |
| conll-to-sling.cc           | Converter from CoNLL format to SLING          |
| README.md                   | This file                                     |

Using these file, you can train a SLING parser model:

```
mkdir local/embeddings
curl -o local/embeddings/word2vec-32-embeddings.bin http://www.jbox.dk/sling/word2vec-32-embeddings.bin

./nlp/parser/tools/train.sh \
  --commons=local/conll2003/commons \
  --train=local/conll2003/eng.train.zip \
  --dev=local/conll2003/eng.testa.zip \
  --word_embeddings=local/embeddings/word2vec-32-embeddings.bin \
  --report_every=5000 \
  --train_steps=10000 \
  --output=/tmp/sempar-conll
```

## Building the corpora

This archive contains conversions of the CoNLL corpora in SLING format that can
be used for training a parser. However, the `conll-to-sling` tool can be used to
create these corpora from the original CoNLL 2003 files:

```
bazel build -c opt local/conll2003:conll-to-sling

mkdir -p /tmp/train /tmp/testa /tmp/testb
curl -o local/sempar.flow http://www.jbox.dk/sling/sempar.flow

bazel-bin/local/conll2003/conll-to-sling --parser local/sempar.flow --conll local/conll2003/eng.train --output /tmp/train
bazel-bin/local/conll2003/conll-to-sling --parser local/sempar.flow --conll local/conll2003/eng.testa --output /tmp/testa
bazel-bin/local/conll2003/conll-to-sling --parser local/sempar.flow --conll local/conll2003/eng.testb --output /tmp/testb

zip -r local/conll2003/eng.train.zip /tmp/train/sent*
zip -r local/conll2003/eng.testa.zip /tmp/testa/sent*
zip -r local/conll2003/eng.testb.zip /tmp/testb/sent*
```

The script in [sling/nlp/parser/tools/build-commons.sh](https://github.com/google/sling/blob/master/nlp/parser/tools/build-commons.sh)
can be used for building the commons store.

